@@ -1,5 +1,5 @@
 from pl_bolts.models.self_supervised.cpc.cpc_module import CPCV2
-from pl_bolts.models.self_supervised.cpc.networks import CPCResNet101
+from pl_bolts.models.self_supervised.cpc.networks import cpc_resnet101, cpc_resnet50
 from pl_bolts.models.self_supervised.cpc.transforms import (
     CPCTrainTransformsCIFAR10,
     CPCEvalTransformsCIFAR10,
