@@ -1,4 +1,9 @@
-from torchvision import transforms
+from warnings import warn
+try:
+    from torchvision import transforms
+except ImportError:
+    warn('You want to use `torchvision` which is not installed yet,'  # pragma: no-cover
+                      ' install it with `pip install torchvision`.')
 
 
 def imagenet_normalization():
